@@ -1,3 +1,14 @@
+"""
+In this tool we use the Model View Controller (MVC) design pattern.
+The MCV can be considered an approach to distinguish between the data model, processing control and the user interface.
+It neatly separates the graphical interface displayed to the user from the code that manages the user actions.
+
+In this file we define the 'Boxmanager_controller' which has the logic that binds model (boxmanager_model.py) and view
+(boxmanager_view.py). Accepts input and converts it to commands for the model or view
+
+Except for the 'run' function all the other function are just calling the function defined in the helper files
+"""
+
 from sys import exit as sys_exit
 from os import path
 from cryoloBM import logic_dropdown_menu, helper_image, import_data, helper_tab_thresholding, helper_tab_tracing,writer,constants,helper_GUI,helper
@@ -5,6 +16,11 @@ from cryoloBM import boxmanager_model, boxmanager_view   # for type hinting purp
 
 class Boxmanager_controller:
     def __init__(self, model:boxmanager_model, view:boxmanager_view, app:helper_GUI.QtG)->None:
+        """
+        :param model: Boxmanager_model obj
+        :param view: Boxmanager_view obj
+        :param app: QTWidgets object
+        """
         self.model = model
         self.view = view
         self.app = app
@@ -22,6 +38,9 @@ class Boxmanager_controller:
 
 
     def run(self)->None:
+        """
+        This function run the boxmanager
+        """
         self.view.setup(self)
 
         # manage the run via command line
@@ -239,61 +258,119 @@ class Boxmanager_controller:
 
     # THRESHOLDING TAB OPTION
     def conf_thresh_changed(self)->None:
+        """
+        It is called when the 'confidence threshold', present in thresholding tab, is changed
+        """
         helper_tab_thresholding.conf_thresh_changed(self)
 
     def conf_thresh_label_changed(self)->None:
+        """
+        It is called when the label of the 'confidence threshold', present in thresholding tab, is changed
+        """
         helper_tab_thresholding.conf_thresh_label_changed(self)
 
     def lower_size_thresh_changed(self)->None:
+        """
+        It is called when the 'lower size of the confidence threshold', present in thresholding tab, is changed
+        """
         helper_tab_thresholding.lower_size_thresh_changed(self)
 
     def lower_size_label_changed(self)->None:
+        """
+        It is called when the label of 'lower size of the confidence threshold', present in thresholding tab, is changed
+        """
         helper_tab_thresholding.lower_size_label_changed(self)
 
     def upper_size_thresh_changed(self)->None:
+        """
+        It is called when the 'upper size of the confidence threshold', present in thresholding tab, is changed
+        """
         helper_tab_thresholding.upper_size_thresh_changed(self)
 
     def upper_size_label_changed(self)->None:
+        """
+        It is called when the label of 'upper size of the confidence threshold', present in thresholding tab, is changed
+        """
         helper_tab_thresholding.upper_size_label_changed(self)
 
     # TRACING OPTION
     def searchRange_changed(self)->None:
+        """
+        It is called when the 'search range', present in tracing tab, is changed
+        """
         helper_tab_tracing.searchRange_changed(self)
 
     def searchRange_label_changed(self)->None:
+        """
+        It is called when the label of the 'search range', present in tracing tab, is changed
+        """
         helper_tab_tracing.searchRange_label_changed(self)
 
     def memory_changed(self)->None:
+        """
+        It is called when the 'memory', present in tracing tab, is changed
+        """
         helper_tab_tracing.memory_changed(self)
 
     def memory_label_changed(self)->None:
+        """
+        It is called when the label of the 'memory', present in tracing tab, is changed
+        """
         helper_tab_tracing.memory_label_changed(self)
 
     def min_length_changed(self)->None:
+        """
+        It is called when the 'min lenght', present in tracing tab, is changed
+        """
         helper_tab_tracing.min_length_changed(self)
 
     def min_length_label_changed(self)->None:
+        """
+        It is called when the label of the 'min lenght', present in tracing tab, is changed
+        """
         helper_tab_tracing.min_length_label_changed(self)
 
     def min_edge_weight_changed(self)->None:
+        """
+        It is called when the 'min edge weight', present in tracing tab, is changed
+        """
         helper_tab_tracing.min_edge_weight_changed(self)
 
     def min_edge_weight_label_changed(self)->None:
+        """
+        It is called when the label of the 'min edge weight', present in tracing tab, is changed
+        """
         helper_tab_tracing.min_edge_weight_label_changed(self)
 
     def win_size_changed(self)->None:
+        """
+        It is called when the 'win size', present in tracing tab, is changed
+        """
         helper_tab_tracing.win_size_changed(self)
 
     def win_size_label_changed(self)->None:
+        """
+        It is called when the label of the 'win size', present in tracing tab, is changed
+        """
         helper_tab_tracing.win_size_label_changed(self)
 
     def preview(self)->None:
+        """
+        it is called when the tracing is done and show the image with the tracing results
+        """
         helper_tab_tracing.preview(self)
 
     def trace(self)->None:
+        """
+        It starts the tracing
+        """
         helper_tab_tracing.trace(self)
 
     def set_has_filament(self, has_filament:bool)->None:
+        """
+        Set the 'has_filament' internal vars
+        :param has_filament: True if we use filaments. Otherwise False
+        """
         self.model.has_filament = has_filament
         if self.model.box_dictionary:
             self.model.box_dictionary.has_filament = has_filament
\ No newline at end of file
