@@ -1,5 +1,9 @@
 """
-In this file the 'Boxmanager_model' class for defining the model of the 'model-view-controller' paradigma is create
+In this tool we use the Model View Controller (MVC) design pattern.
+The MCV can be considered an approach to distinguish between the data model, processing control and the user interface.
+It neatly separates the graphical interface displayed to the user from the code that manages the user actions.
+
+In this file we define the 'Boxmanager_model' which deals with the data
 """
 
 from cryoloBM import constants,box_dictionary,helper
@@ -58,7 +62,7 @@ class Boxmanager_model:
             # when loaded from '.cbox', and should be never changed
         self.est_box_from_cbox = None   # est_size got from cryolo
         self.is_cbox = False            # the data are in cbox format
-        self.is_cbox_untraced = False   # the data are in cbox format and represent untraced particles/filaments
+        self.is_cbox_untraced = True   # the data are in cbox format and represent untraced particles/filaments
         self.has_filament = False       # the data are filament
         self.has_3d = False             # the 3D visualization is available (only cbox tomo cases. when untraced box are not loaded)
 
@@ -190,7 +194,7 @@ class Boxmanager_model:
 
         # info about the imported boxes:
         self.is_cbox = False
-        self.is_cbox_untraced = False
+        self.is_cbox_untraced = True
         self.has_filament = False
         self.est_box_from_cbox = None
 
