@@ -1,4 +1,7 @@
-""" In this file there are some functions to manage the GUI and the pyQT import """
+"""
+In this file there are some functions to manage the GUI and the pyQT import
+"""
+
 try:
     QT = 4
     import PyQt4.QtGui as QtG
