@@ -1,3 +1,14 @@
+"""
+In this file are implemented all the function used for interacting with the image in the GUI, for istance:
+-) 'onclick' when you click on the image
+-) 'onrelease' when you release the button after clicking on the image
+-) 'box_size_changed' when the boxsize is changed
+-) 'remove_picked_filament' for removing a filament
+....
+....
+"""
+
+
 from cryoloBM import constants,helper, helper_GUI, MySketch,visualization_3D_Window, helper_tab_tracing, helper_filament
 from cryolo import imagereader
 from os import path
@@ -62,8 +73,12 @@ def _set_and_update_boxdictionary_image_changed(controller:boxmanager_controller
 
     # load the sketches present in the current image/slice. If i need i resize them
     # NB the untraced cbox sketches are treat as 2D particle
-    if (not controller.model.is_cbox_untraced and  controller.model.box_dictionary.has_same_boxsize(boxsize=controller.model.boxsize, f=current_filename, n=controller.model.index_tomo))\
+    is_untraced = controller.model.is_cbox_untraced
+    has_same_boxsize = controller.model.box_dictionary.has_same_boxsize(boxsize=controller.model.boxsize, f=current_filename, n=controller.model.index_tomo)
+
+    if (not is_untraced and has_same_boxsize)\
             or(controller.model.has_filament and controller.model.has_3d):
+
         controller.model.rectangles = controller.model.box_dictionary.get_sketches(f=current_filename,
                                                         n=controller.model.index_tomo, is_3D =True,  is_tracing = False)
     else:
@@ -99,7 +114,6 @@ def event_image_changed(controller:boxmanager_controller, root_tree_item:helper_
     # they are already present in controller.model.rectangle
     if controller.model.box_dictionary:
         delete_all_patches(controller=controller)
-
         # set vars to identify current image/slice
         if controller.model.type_case == constants.Type_case.SPA.value:
             helper.set_current_image_path(controller=controller, current_image_path=path.join(controller.model.image_folder_path,
@@ -133,7 +147,9 @@ def event_image_changed(controller:boxmanager_controller, root_tree_item:helper_
                 controller.view.memory_slider.setMaximum(controller.model.tot_frames[pure_filename] - 1)
                 controller.view.min_length_slider.setMaximum(controller.model.tot_frames[pure_filename] - 1)
                 controller.view.search_range_slider.setMaximum(controller.model.smallest_image_dim[pure_filename] - 1)
+                oldsize_single_slice=controller.model.current_tomoimage_mmap.shape[1:3]
                 controller.model.current_tomoimage_mmap = helper.read_image(file_path=controller.model.current_image_path, use_mmap=True)
+                new_size_img = controller.model.current_tomoimage_mmap.shape[1:3] != oldsize_single_slice
                 helper.load_tomo_params(controller=controller,pure_filename=pure_filename)
 
         img = controller.model.current_tomoimage_mmap[controller.model.index_tomo, :, :]
@@ -793,7 +809,6 @@ def delete_box(controller:boxmanager_controller, box:MySketch.MySketch, f:str, n
         draw_all_patches(controller=controller)
         controller.view.fig.canvas.blit(controller.view.ax.bbox)
 
-#todo it is buggy. See tests/test_remove_filament.py
 def is_click_into_box(fil:MySketch.MySketch,x:float,y:float,boxsize:int,is_tomo:bool)->bool:
     """
     Return True if thce click (x,y) is into the filament
