@@ -387,16 +387,19 @@ def write_coordinates_tomo(controller: boxmanager_controller,
                     box = BoundBox(x=x_lowerleft, y=y_lowerleft, w=boxize, h=boxize, c=confidence, z=n,depth=1)
                     boxes.append(box)
 
-
-            if is_cbox:
-                # there is a case where i pass to this function empty_slice=ignored_slice=[]
-                empty = empty_slice[f] if empty_slice else list()
-                ignored = ignored_slice[f] if ignored_slice else list()
-                write_coords_(box_file_path, boxes, empty, ignored)
-            else:
-                write_coords_(box_file_path, boxes)
-
             counter = counter + 1
+
+        if is_cbox:
+            # there is a case where i pass to this function empty_slice=ignored_slice=[]
+            empty = empty_slice[f] if empty_slice else list()
+            ignored = ignored_slice[f] if ignored_slice else list()
+            if len(empty)==0 and len(boxes)==0:
+                continue
+            write_coords_(box_file_path, boxes, empty, ignored)
+        else:
+            write_coords_(box_file_path, boxes)
+
+
     if controller.model.has_filament:
         print(f"{controller.model.box_dictionary.get_tot_filament(tomo_name=None)} filaments written in '{file_ext}' file.")
     else:
